ManoPot
========

ManoPot is a simple TCP HoneyPot written in Python 3.

Source Code
------------

https://github.com/Rand0mAccess/ManoPot

PyPI package
------------

https://pypi.org/project/manopot/

Documentation
-------------

http://manopot.rtfd.io/

Documentation can also be found in the 'docs/' directory as reStructuredText files. Build the docs by running 'make'
in the 'docs/' directory, then viewing 'docs/_build/html/index.html'.
